@@ -30,6 +30,37 @@
 
 G_BEGIN_DECLS
 
+/**
+ * ECalClientSourceType:
+ *
+ * FIXME: Document me!
+ *
+ * Since: 3.2
+ **/
+typedef enum {
+	E_CAL_CLIENT_SOURCE_TYPE_EVENTS,
+	E_CAL_CLIENT_SOURCE_TYPE_TASKS,
+	E_CAL_CLIENT_SOURCE_TYPE_MEMOS,
+	E_CAL_CLIENT_SOURCE_TYPE_LAST  /*< skip >*/
+} ECalClientSourceType;
+
+/**
+ * ECalObjModType:
+ *
+ * FIXME Document me!
+ *
+ * Since: 3.8
+ **/
+typedef enum {
+	E_CAL_OBJ_MOD_THIS            = 1 << 0,
+	E_CAL_OBJ_MOD_THIS_AND_PRIOR  = 1 << 1,
+	E_CAL_OBJ_MOD_THIS_AND_FUTURE = 1 << 2,
+	E_CAL_OBJ_MOD_ALL             = 0x07,
+	E_CAL_OBJ_MOD_ONLY_THIS       = 1 << 3
+} ECalObjModType;
+
+/** Everything below this point is deprecated. **/
+
 #ifndef EDS_DISABLE_DEPRECATED
 
 #define E_CALENDAR_ERROR e_calendar_error_quark()
@@ -80,22 +111,6 @@ typedef enum {
 
 #define E_CALENDAR_STATUS_CORBA_EXCEPTION E_CALENDAR_STATUS_DBUS_EXCEPTION
 
-#endif /* EDS_DISABLE_DEPRECATED */
-
-/**
- * ECalClientSourceType:
- *
- * FIXME: Document me!
- *
- * Since: 3.2
- **/
-typedef enum {
-	E_CAL_CLIENT_SOURCE_TYPE_EVENTS,
-	E_CAL_CLIENT_SOURCE_TYPE_TASKS,
-	E_CAL_CLIENT_SOURCE_TYPE_MEMOS,
-	E_CAL_CLIENT_SOURCE_TYPE_LAST  /*< skip >*/
-} ECalClientSourceType;
-
 /**
  * EDataCalObjType:
  *
@@ -124,7 +139,16 @@ typedef enum {
 	All = 0x07
 } EDataCalObjModType;
 
+typedef ECalObjModType CalObjModType;
+#define CALOBJ_MOD_THIS          E_CAL_OBJ_MOD_THIS
+#define CALOBJ_MOD_THISANDPRIOR  E_CAL_OBJ_MOD_THIS_AND_PRIOR
+#define CALOBJ_MOD_THISANDFUTURE E_CAL_OBJ_MOD_THIS_AND_FUTURE
+#define CALOBJ_MOD_ALL           E_CAL_OBJ_MOD_ALL
+#define CALOBJ_MOD_ONLY_THIS     E_CAL_OBJ_MOD_ONLY_THIS
+
+#endif /* EDS_DISABLE_DEPRECATED */
+
 G_END_DECLS
 
-#endif
+#endif /* E_CAL_TYPES_H */
 
