@@ -465,12 +465,7 @@ camel_search_header_match (const gchar *value,
 		 * which should be common. */
 		vdom = strchr (value, '@');
 		mdom = strchr (match, '@');
-		if (mdom == NULL && vdom != NULL) {
-			v = g_alloca (vdom - value + 1);
-			memcpy (v, value, vdom - value);
-			v[vdom - value] = 0;
-			value = (gchar *) v;
-		} else if (mdom != NULL && vdom == NULL) {
+		if (mdom != NULL && vdom == NULL) {
 			v = g_alloca (mdom - match + 1);
 			memcpy (v, match, mdom - match);
 			v[mdom - match] = 0;
@@ -541,7 +536,7 @@ camel_search_message_body_contains (CamelDataWrapper *object,
 
 		byte_array = g_byte_array_new ();
 		stream = camel_stream_mem_new_with_byte_array (byte_array);
-		camel_data_wrapper_write_to_stream_sync (
+		camel_data_wrapper_decode_to_stream_sync (
 			containee, stream, NULL, NULL);
 		camel_stream_write (stream, "", 1, NULL, NULL);
 		truth = regexec (pattern, (gchar *) byte_array->data, 0, NULL, 0) == 0;
